@@ -1,14 +1,16 @@
 from .select import Select
 from .common_table_expression import CommonTableExpression
 from .union import Union
-from .constant import Constant, NullConstant, SpecialConstant
+from .constant import Constant, NullConstant, Last
 from .star import Star
 from .identifier import Identifier
 from .join import Join
 from .type_cast import TypeCast
 from .tuple import Tuple
-from .operation import Operation, BinaryOperation, UnaryOperation, BetweenOperation, Function, WindowFunction, Object
+from .operation import (Operation, BinaryOperation, UnaryOperation, BetweenOperation,
+                        Function, WindowFunction, Object, Interval)
 from .order_by import OrderBy
 from .parameter import Parameter
 from .case import Case
 from .native_query import NativeQuery
+from .data import Data
