@@ -7,6 +7,7 @@ class CreateView(ASTNode):
                  name,
                  query_str,
                  from_table=None,
+                 if_not_exists=False,
                  *args, **kwargs):
         super().__init__(*args, **kwargs)
         # todo remove it
@@ -15,6 +16,7 @@ class CreateView(ASTNode):
         self.name = name
         self.query_str = query_str
         self.from_table = from_table
+        self.if_not_exists = if_not_exists
 
     def to_tree(self, *args, level=0, **kwargs):
         ind = indent(level)
@@ -23,8 +25,10 @@ class CreateView(ASTNode):
         # name_str = f'\n{ind1}name={self.name.to_string()},'
         from_table_str = f'\n{ind1}from_table=\n{self.from_table.to_tree(level=level+2)},' if self.from_table else ''
         query_str = f'\n{ind1}query="{self.query_str}"'
+        if_not_exists_str = f'\n{ind1}if_not_exists=True,' if self.if_not_exists else ''
 
         out_str = f'{ind}CreateView(' \
+                  f'{if_not_exists_str}' \
                   f'{name_str}' \
                   f'{query_str}' \
                   f'{from_table_str}' \
@@ -34,7 +38,7 @@ class CreateView(ASTNode):
     def get_string(self, *args, **kwargs):
         from_str = f'FROM {str(self.from_table)} ' if self.from_table else ''
         # out_str = f'CREATE VIEW {self.name.to_string()} {from_str}AS ( {self.query_str} )'
-        out_str = f'CREATE VIEW {str(self.name)} {from_str}AS ( {self.query_str} )'
+        out_str = f'CREATE VIEW {"IF NOT EXISTS " if self.if_not_exists else ""}{str(self.name)} {from_str}AS ( {self.query_str} )'
 
         return out_str
 
