@@ -5,9 +5,11 @@ from mindsdb_sql.parser.utils import indent
 class DropDatasource(Drop):
     def __init__(self,
                  name,
+                 if_exists=False,
                  *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.name = name
+        self.if_exists = if_exists
 
     def to_tree(self, *args, level=0, **kwargs):
         ind = indent(level)
@@ -15,11 +17,12 @@ class DropDatasource(Drop):
         name_str = f'\n{ind1}name={self.name.to_tree()},'
 
         out_str = f'{ind}DropDatasource(' \
+                  f'{ind1}if_exists={self.if_exists},' \
                   f'{name_str}' \
                   f'\n{ind})'
         return out_str
 
     def get_string(self, *args, **kwargs):
-        out_str = f'DROP DATASOURCE {str(self.name)}'
+        out_str = f'DROP DATASOURCE {"IF EXISTS " if self.if_exists else ""}{str(self.name)}'
         return out_str
 
