@@ -25,7 +25,7 @@ class SQLLexer(Lexer):
         VIEW, VARIABLES, SESSION, STATUS,
         GLOBAL, PROCEDURE, FUNCTION, INDEX, WARNINGS,
         ENGINES, CHARSET, COLLATION, PLUGINS, CHARACTER,
-        PERSIST, PERSIST_ONLY, DEFAULT,
+        PERSIST, PERSIST_ONLY,
         IF_EXISTS, COLUMNS, FIELDS, COLLATE,
 
         # SELECT Keywords
@@ -109,7 +109,6 @@ class SQLLexer(Lexer):
     PLUGINS = r'\bPLUGINS\b'
     PERSIST = r'\bPERSIST\b'
     PERSIST_ONLY = r'\bPERSIST_ONLY\b'
-    DEFAULT = r'\bDEFAULT\b'
     IF_EXISTS = r'\bIF[\s]+EXISTS\b'
     COLUMNS = r'\bCOLUMNS\b'
     FIELDS = r'\bFIELDS\b'
@@ -195,7 +194,7 @@ class SQLLexer(Lexer):
     DIVIDE = r'/'
     MODULO = r'%'
     EQUALS = r'='
-    NEQUALS = r'!='
+    NEQUALS = r'(!=|<>)'
     GEQ = r'>='
     GREATER = r'>'
     LEQ = r'<='
@@ -219,7 +218,7 @@ class SQLLexer(Lexer):
     TRUE = r'\bTRUE\b'
     FALSE = r'\bFALSE\b'
 
-    @_(r'(?:([a-zA-Z_$0-9]*[a-zA-Z_$]+[a-zA-Z_$0-9]*)|(?:`([^`]+)`))(?:\.(?:([a-zA-Z_$0-9]*[a-zA-Z_$]+[a-zA-Z_$0-9]*)|(?:`([^`]+)`)))*')
+    @_(r'(?:([a-zA-Z_$0-9]*[a-zA-Z_$]+[a-zA-Z_$0-9]*)|(?:`([^`]+)`))')
     def ID(self, t):
         return t
 
@@ -242,4 +241,3 @@ class SQLLexer(Lexer):
     @_(r'\n+')
     def ignore_newline(self, t):
         self.lineno += len(t.value)
-
