@@ -1,3 +1,4 @@
+from mindsdb_sql import OrderBy
 from mindsdb_sql.exceptions import PlanningException
 from mindsdb_sql.parser.ast import Identifier, Operation, BinaryOperation, BetweenOperation
 
@@ -65,8 +66,28 @@ def validate_ts_where_condition(op, allowed_columns, allow_and=True):
             if arg.parts[-1].lower() not in allowed_columns:
                 raise PlanningException(
                     f'For time series predictor only the following columns are allowed in WHERE: {str(allowed_columns)}, found instead: {str(arg)}.')
+            # remove alias
+            arg.parts = [arg.parts[-1]]
 
     if isinstance(op.args[0], Operation):
         validate_ts_where_condition(op.args[0], allowed_columns, allow_and=True)
     if isinstance(op.args[1], Operation):
-        validate_ts_where_condition(op.args[1], allowed_columns, allow_and=True)
\ No newline at end of file
+        validate_ts_where_condition(op.args[1], allowed_columns, allow_and=True)
+
+
+def recursively_check_join_identifiers_for_ambiguity(item, aliased_fields=None):
+    if item is None:
+        return
+    elif isinstance(item, Identifier):
+        if len(item.parts) == 1:
+            if aliased_fields is not None and item.parts[0] in aliased_fields:
+                # is alias
+                return
+            raise PlanningException(f'Ambigous identifier {str(item)}, provide table name for operations on a join.')
+    elif isinstance(item, Operation):
+        recursively_check_join_identifiers_for_ambiguity(item.args, aliased_fields=aliased_fields)
+    elif isinstance(item, OrderBy):
+        recursively_check_join_identifiers_for_ambiguity(item.field, aliased_fields=aliased_fields)
+    elif isinstance(item, list):
+        for arg in item:
+            recursively_check_join_identifiers_for_ambiguity(arg, aliased_fields=aliased_fields)
