@@ -1,18 +1,39 @@
+import re
 import datetime as dt
 
 import sqlalchemy as sa
 from sqlalchemy.exc import SQLAlchemyError
-from sqlalchemy.orm.query import aliased
-from sqlalchemy.dialects import mysql, postgresql, sqlite, mssql, firebird, oracle, sybase
+from sqlalchemy.ext.compiler import compiles
+from sqlalchemy.orm import aliased
+from sqlalchemy.dialects import mysql, postgresql, sqlite, mssql, oracle
 from sqlalchemy.schema import CreateTable, DropTable
+from sqlalchemy.sql import ColumnElement
+from sqlalchemy.sql import functions as sa_fnc
 
 from mindsdb_sql.parser import ast
 
 
+sa_type_names = [
+    key for key, val in sa.types.__dict__.items() if hasattr(val, '__module__')
+    and val.__module__ in ('sqlalchemy.sql.sqltypes', 'sqlalchemy.sql.type_api')
+]
+
+
 class RenderError(Exception):
     ...
 
 
+# https://github.com/sqlalchemy/sqlalchemy/discussions/9483?sort=old#discussioncomment-5312979
+class INTERVAL(ColumnElement):
+    def __init__(self, info):
+        self.info = info
+        self.type = sa.Interval()
+
+@compiles(INTERVAL)
+def _compile_interval(element, compiler, **kw):
+    return f"INTERVAL '{element.info}'"
+
+
 class SqlalchemyRender:
 
     def __init__(self, dialect_name):
@@ -22,9 +43,7 @@ class SqlalchemyRender:
             'postgres': postgresql,
             'sqlite': sqlite,
             'mssql': mssql,
-            'firebird': firebird,
             'oracle': oracle,
-            'sybase': sybase,
             'Snowflake': oracle,
         }
 
@@ -46,7 +65,7 @@ class SqlalchemyRender:
             self.dialect.server_version_info = (8, 0, 17)
 
         self.types_map = {}
-        for type_name in sa.types.__all__:
+        for type_name in sa_type_names:
             self.types_map[type_name.upper()] = getattr(sa.types, type_name)
 
     def to_column(self, parts):
@@ -83,6 +102,8 @@ class SqlalchemyRender:
 
         if isinstance(t, ast.Star):
             col = sa.text('*')
+        elif isinstance(t, ast.Last):
+            col = self.to_column(['last'])
         elif isinstance(t, ast.Constant):
             col = sa.literal(t.value)
             if t.alias:
@@ -94,7 +115,20 @@ class SqlalchemyRender:
                     alias = str(t.value)
             col = col.label(alias)
         elif isinstance(t, ast.Identifier):
-            col = self.to_column(t.parts)
+            # sql functions
+            col = None
+            if len(t.parts) == 1:
+                name = t.parts[0].upper()
+                if name == 'CURRENT_DATE':
+                    col = sa_fnc.current_date()
+                elif name == 'CURRENT_TIME':
+                    col = sa_fnc.current_time()
+                elif name == 'CURRENT_TIMESTAMP':
+                    col = sa_fnc.current_timestamp()
+                elif name == 'CURRENT_USER':
+                    col = sa_fnc.current_user()
+            if col is None:
+                col = self.to_column(t.parts)
             if t.alias:
                 col = col.label(self.get_alias(t.alias))
         elif isinstance(t, ast.Select):
@@ -104,36 +138,22 @@ class SqlalchemyRender:
                 alias = self.get_alias(t.alias)
                 col = col.label(alias)
         elif isinstance(t, ast.Function):
-            op = getattr(sa.func, t.op)
-            if t.from_arg is not None:
-                arg = t.args[0].to_string()
-                from_arg = self.to_expression(t.from_arg)
-
-                col = op(arg, from_arg)
-            else:
-                args = [
-                    self.to_expression(i)
-                    for i in t.args
-                ]
-                if t.distinct:
-                    # set first argument to distinct
-                    args[0] = args[0].distinct()
-                col = op(*args)
-
+            fnc = self.to_function(t)
             if t.alias:
                 alias = self.get_alias(t.alias)
             else:
                 alias = str(t.op)
-            col = col.label(alias)
+            col = fnc.label(alias)
         elif isinstance(t, ast.BinaryOperation):
             methods = {
                 "+": "__add__",
                 "-": "__sub__",
-                "/": "__div__",
+                "/": "__truediv__",
                 "*": "__mul__",
                 "%": "__mod__",
                 "=": "__eq__",
                 "!=": "__ne__",
+                "<>": "__ne__",
                 ">": "__gt__",
                 "<": "__lt__",
                 ">=": "__ge__",
@@ -141,6 +161,7 @@ class SqlalchemyRender:
                 "is": "is_",
                 "is not": "is_not",
                 "like": "like",
+                "not like": "notlike",
                 "in": "in_",
                 "not in": "notin_",
                 "||": "concat",
@@ -163,9 +184,11 @@ class SqlalchemyRender:
                 sa_op = getattr(arg0, method)
 
                 col = sa_op(arg1)
-            else:
+            elif t.op.lower() in functions:
                 func = functions[t.op.lower()]
                 col = func(arg0, arg1)
+            else:
+                col = arg0.op(t.op)(arg1)
 
             if t.alias:
                 alias = self.get_alias(t.alias)
@@ -191,6 +214,12 @@ class SqlalchemyRender:
             lim_up = self.to_expression(t.args[2])
 
             col = sa.between(col0, lim_down, lim_up)
+        elif isinstance(t, ast.Interval):
+            col = INTERVAL(t.args[0])
+            if t.alias:
+                alias = self.get_alias(t.alias)
+                col = col.label(alias)
+
         elif isinstance(t, ast.WindowFunction):
             func = self.to_expression(t.function)
 
@@ -246,6 +275,24 @@ class SqlalchemyRender:
 
         return col
 
+    def to_function(self, t):
+        op = getattr(sa.func, t.op)
+        if t.from_arg is not None:
+            arg = t.args[0].to_string()
+            from_arg = self.to_expression(t.from_arg)
+
+            fnc = op(arg, from_arg)
+        else:
+            args = [
+                self.to_expression(i)
+                for i in t.args
+            ]
+            if t.distinct:
+                # set first argument to distinct
+                args[0] = args[0].distinct()
+            fnc = op(*args)
+        return fnc
+
     def get_type(self, typename):
         # TODO how to get type
         if not isinstance(typename, str):
@@ -253,8 +300,10 @@ class SqlalchemyRender:
             return typename
 
         typename = typename.upper()
-        if typename == 'INT64':
+        if re.match('^INT[\d]*$', typename):
             typename = 'BIGINT'
+        if re.match('^FLOAT[\d]*$', typename):
+            typename = 'FLOAT'
         type = self.types_map[typename]
         return type
 
@@ -330,7 +379,7 @@ class SqlalchemyRender:
             col = self.to_expression(t)
             cols.append(col)
 
-        query = sa.select(cols)
+        query = sa.select(*cols)
 
         if node.cte is not None:
             for cte in node.cte:
@@ -382,17 +431,17 @@ class SqlalchemyRender:
                             full=is_full
                         )
             elif isinstance(from_table, ast.Union):
-                if not(isinstance(from_table.left, ast.Select) and isinstance(from_table.right, ast.Select)):
-                    raise NotImplementedError(f'Unknown UNION {from_table.left.__name__}, {from_table.right.__name__}')
-
-                left = self.prepare_select(from_table.left)
-                right = self.prepare_select(from_table.right)
+                tables = self.extract_union_list(from_table)
 
                 alias = None
                 if from_table.alias:
                     alias = self.get_alias(from_table.alias)
 
-                table = left.union(right).subquery(alias)
+                table1 = tables[1]
+                tables_x = tables[1:]
+
+                table = table1.union(*tables_x).subquery(alias)
+
                 query = query.select_from(table)
 
             elif isinstance(from_table, ast.Select):
@@ -402,6 +451,13 @@ class SqlalchemyRender:
             elif isinstance(from_table, ast.Identifier):
                 table = self.to_table(from_table)
                 query = query.select_from(table)
+
+            elif isinstance(from_table, ast.NativeQuery):
+                alias = None
+                if from_table.alias:
+                    alias = from_table.alias.parts[-1]
+                table = sa.text(from_table.query).columns().subquery(alias)
+                query = query.select_from(table)
             else:
                 raise NotImplementedError(f'Select from {from_table}')
 
@@ -450,14 +506,38 @@ class SqlalchemyRender:
 
         return query
 
+    def extract_union_list(self, node):
+        if not (isinstance(node.left, (ast.Select, ast.Union)) and isinstance(node.right, ast.Select)):
+            raise NotImplementedError(
+                f'Unknown UNION {node.left.__class__.__name__}, {node.right.__class__.__name__}')
+
+        tables = []
+        if isinstance(node.left, ast.Union):
+            tables.extend(self.extract_union_list(node.left))
+        else:
+            tables.append(self.prepare_select(node.left))
+        tables.append(self.prepare_select(node.right))
+        return tables
+
+
     def prepare_create_table(self, ast_query):
-        columns = [
-            sa.Column(
-                col.name,
-                self.get_type(col.type)
+        columns = []
+
+        for col in ast_query.columns:
+            default = None
+            if col.default is not None:
+                if isinstance(col.default, ast.Function):
+                    default = self.to_function(col.default)
+
+            columns.append(
+                sa.Column(
+                    col.name,
+                    self.get_type(col.type),
+                    primary_key=col.is_primary_key,
+                    default=default,
+                )
             )
-            for col in ast_query.columns
-        ]
+
         schema, table_name = self.get_table_name(ast_query.name)
 
         metadata = sa.MetaData()
@@ -550,29 +630,34 @@ class SqlalchemyRender:
 
         return stmt
 
+    def get_query(self, ast_query):
+        if isinstance(ast_query, ast.Select):
+            stmt = self.prepare_select(ast_query)
+        elif isinstance(ast_query, ast.Insert):
+            stmt = self.prepare_insert(ast_query)
+        elif isinstance(ast_query, ast.Update):
+            stmt = self.prepare_update(ast_query)
+        elif isinstance(ast_query, ast.CreateTable):
+            stmt = self.prepare_create_table(ast_query)
+        elif isinstance(ast_query, ast.DropTables):
+            stmt = self.prepare_drop_table(ast_query)
+        else:
+            raise NotImplementedError(f'Unknown statement: {ast_query.__class__.__name__}')
+        return stmt
+
     def get_string(self, ast_query, with_failback=True):
+        if isinstance(ast_query, (ast.CreateTable, ast.DropTables)):
+            render_func = render_ddl_query
+        else:
+            render_func = render_dml_query
+
         try:
-            if isinstance(ast_query, ast.Select):
-                stmt = self.prepare_select(ast_query)
-                sql = render_dml_query(stmt, self.dialect)
-            elif isinstance(ast_query, ast.Insert):
-                stmt = self.prepare_insert(ast_query)
-                sql = render_dml_query(stmt, self.dialect)
-            elif isinstance(ast_query, ast.Update):
-                stmt = self.prepare_update(ast_query)
-                sql = render_dml_query(stmt, self.dialect)
-            elif isinstance(ast_query, ast.CreateTable):
-                stmt = self.prepare_create_table(ast_query)
-                sql = render_ddl_query(stmt, self.dialect)
-            elif isinstance(ast_query, ast.DropTables):
-                stmt = self.prepare_drop_table(ast_query)
-                sql = render_ddl_query(stmt, self.dialect)
-            else:
-                raise NotImplementedError(f'Unknown statement: {ast_query.__class__.__name__}')
+            stmt = self.get_query(ast_query)
+
+            sql = render_func(stmt, self.dialect)
 
             return sql
 
-
         except (SQLAlchemyError, NotImplementedError) as e:
             if not with_failback:
                 raise e
